import { h, defineComponent, inject, Fragment } from 'vue';
import { happensIn, pxfy } from 'seemly';
import { formatLength } from '../../../_utils';
import { NCheckbox } from '../../../checkbox';
import { NEllipsis } from '../../../ellipsis';
import SortButton from '../HeaderButton/SortButton';
import FilterButton from '../HeaderButton/FilterButton';
import { isColumnSortable, isColumnFilterable, createNextSorter, getColKey } from '../utils';
import { dataTableInjectionKey } from '../interface';
import SelectionMenu from './SelectionMenu';
function renderTitle(column) {
    return typeof column.title === 'function'
        ? column.title(column)
        : column.title;
}
export default defineComponent({
    name: 'DataTableHeader',
    props: {
        discrete: {
            type: Boolean,
            default: true
        }
    },
    setup() {
        const { mergedClsPrefixRef, scrollXRef, fixedColumnLeftMapRef, fixedColumnRightMapRef, mergedCurrentPageRef, allRowsCheckedRef, someRowsCheckedRef, rowsRef, colsRef, mergedThemeRef, checkOptionsRef, mergedSortStateRef, componentId, scrollPartRef, tableLayoutRef, handleTableBodyScroll, doUpdateSorter, doUncheckAll, doCheckAll
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
         } = inject(dataTableInjectionKey);
        function handleCheckboxUpdateChecked() {
            if (someRowsCheckedRef.value || allRowsCheckedRef.value) {
                doUncheckAll();
            }
            else {
                doCheckAll();
            }
        }
        function handleColHeaderClick(e, column) {
            if (happensIn(e, 'dataTableFilter'))
                return;
            if (!isColumnSortable(column))
                return;
            const activeSorter = mergedSortStateRef.value;
            const nextSorter = createNextSorter(column, activeSorter);
            doUpdateSorter(nextSorter);
        }
        function handleMouseenter() {
            scrollPartRef.value = 'head';
        }
        return {
            componentId,
            mergedSortState: mergedSortStateRef,
            mergedClsPrefix: mergedClsPrefixRef,
            scrollX: scrollXRef,
            fixedColumnLeftMap: fixedColumnLeftMapRef,
            fixedColumnRightMap: fixedColumnRightMapRef,
            currentPage: mergedCurrentPageRef,
            allRowsChecked: allRowsCheckedRef,
            someRowsChecked: someRowsCheckedRef,
            rows: rowsRef,
            cols: colsRef,
            mergedTheme: mergedThemeRef,
            checkOptions: checkOptionsRef,
            tableLayout: tableLayoutRef,
            handleMouseenter,
            handleCheckboxUpdateChecked,
            handleColHeaderClick,
            handleTableBodyScroll
        };
    },
    render() {
        const { mergedClsPrefix, fixedColumnLeftMap, fixedColumnRightMap, currentPage, allRowsChecked, someRowsChecked, mergedSortState, rows, cols, mergedTheme, checkOptions, componentId, discrete, handleColHeaderClick, handleCheckboxUpdateChecked } = this;
        let hasEllipsis = false;
        const theadVNode = (h("thead", { class: `${mergedClsPrefix}-data-table-thead`, "data-n-id": componentId }, rows.map((row) => {
            return (h("tr", { class: `${mergedClsPrefix}-data-table-tr` }, row.map(({ column, colSpan, rowSpan, isLast }) => {
                const key = getColKey(column);
                const { ellipsis } = column;
                if (!hasEllipsis && ellipsis)
                    hasEllipsis = true;
                return (h("th", { key: key, style: {
                        textAlign: column.align,
                        left: pxfy(fixedColumnLeftMap[key]),
                        right: pxfy(fixedColumnRightMap[key])
                    }, colspan: colSpan, rowspan: rowSpan, "data-col-key": key, class: [
                        `${mergedClsPrefix}-data-table-th`,
                        column.fixed &&
                            `${mergedClsPrefix}-data-table-th--fixed-${column.fixed}`,
                        {
                            [`${mergedClsPrefix}-data-table-th--hover`]: (mergedSortState === null || mergedSortState === void 0 ? void 0 : mergedSortState.order) &&
                                mergedSortState.columnKey === key,
                            [`${mergedClsPrefix}-data-table-th--filterable`]: isColumnFilterable(column),
                            [`${mergedClsPrefix}-data-table-th--sortable`]: isColumnSortable(column),
                            [`${mergedClsPrefix}-data-table-th--selection`]: column.type === 'selection',
                            [`${mergedClsPrefix}-data-table-th--last`]: isLast
                        },
                        column.className
                    ], onClick: column.type !== 'selection' &&
                        column.type !== 'expand' &&
                        !('children' in column)
                        ? (e) => {
                            handleColHeaderClick(e, column);
                        }
                        : undefined },
                    column.type === 'selection' ? (h(Fragment, null,
                        h(NCheckbox, { key: currentPage, privateTableHeader: true, checked: allRowsChecked, indeterminate: someRowsChecked, onUpdateChecked: handleCheckboxUpdateChecked }),
                        checkOptions ? (h(SelectionMenu, { clsPrefix: mergedClsPrefix })) : null)) : ellipsis === true || (ellipsis && !ellipsis.tooltip) ? (h("div", { class: `${mergedClsPrefix}-data-table-th__ellipsis` }, renderTitle(column))) // eslint-disable-next-line @typescript-eslint/prefer-optional-chain
                        : ellipsis && ellipsis.tooltip ? (h(NEllipsis, { tooltip: ellipsis.tooltip, theme: mergedTheme.peers.Ellipsis, themeOverrides: mergedTheme.peerOverrides.Ellipsis }, {
                            default: () => renderTitle(column)
                        })) : (renderTitle(column)),
                    isColumnSortable(column) ? (h(SortButton, { column: column })) : null,
                    isColumnFilterable(column) ? (h(FilterButton, { column: column, options: column.filterOptions })) : null));
            })));
        })));
        if (!discrete) {
            return theadVNode;
        }
        const { handleTableBodyScroll, handleMouseenter, scrollX } = this;
        return (h("div", { class: `${mergedClsPrefix}-data-table-base-table-header`, onScroll: handleTableBodyScroll, onMouseenter: handleMouseenter },
            h("table", { ref: "body", class: `${mergedClsPrefix}-data-table-table`, style: {
                    minWidth: formatLength(scrollX),
                    tableLayout: discrete || hasEllipsis ? 'fixed' : this.tableLayout
                } },
                h("colgroup", null, cols.map((col) => (h("col", { key: col.key, style: col.style })))),
                theadVNode)));
    }
});
