import { defineComponent, h, inject, ref } from 'vue';
import NImagePreview from './ImagePreview';
import { imageGroupInjectionKey } from './ImageGroup';
import { useConfig } from '../../_mixins';
const imageProps = {
    width: [String, Number],
    height: [String, Number],
    src: String,
    showToolbar: { type: Boolean, default: true }
};
export default defineComponent({
    name: 'Image',
    props: imageProps,
    setup(props) {
        const imageRef = ref(null);
        const previewInstRef = ref(null);
        const imageGroupHandle = inject(imageGroupInjectionKey, null);
        const { mergedClsPrefixRef } = imageGroupHandle || useConfig(props);
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            groupId: imageGroupHandle === null || imageGroupHandle === void 0 ? void 0 : imageGroupHandle.groupId,
            previewInstRef,
            imageRef,
            handleClick: () => {
                if (imageGroupHandle) {
                    imageGroupHandle.setPreviewSrc(props.src);
                    imageGroupHandle.setThumbnailEl(imageRef.value);
                    imageGroupHandle.toggleShow();
                    return;
                }
                const { value: previewInst } = previewInstRef;
                if (!previewInst)
                    return;
                previewInst.setPreviewSrc(props.src);
                previewInst.setThumbnailEl(imageRef.value);
                previewInst.toggleShow();
            }
        };
    },
    render() {
        const { mergedClsPrefix } = this;
        return this.groupId ? (h("div", { class: `${mergedClsPrefix}-image` },
            h("img", { class: this.groupId, ref: "imageRef", width: this.width, height: this.height, src: this.src, onClick: this.handleClick }))) : (h(NImagePreview, { clsPrefix: mergedClsPrefix, ref: "previewInstRef", showToolbar: this.showToolbar }, {
            default: () => {
                return (h("div", { class: `${mergedClsPrefix}-image` },
                    h("img", { ref: "imageRef", width: this.width, height: this.height, src: this.src, onClick: this.handleClick })));
            }
        }));
    }
});
