"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const _mixins_1 = require("../../_mixins");
const styles_1 = require("../styles");
const _utils_1 = require("../../_utils");
const index_cssr_1 = require("./styles/index.cssr");
const avatarProps = Object.assign(Object.assign({}, _mixins_1.useTheme.props), { size: {
        type: [String, Number],
        default: 'medium'
    }, src: String, circle: {
        type: Boolean,
        default: false
    }, round: {
        type: Boolean,
        default: false
    }, color: String });
exports.default = vue_1.defineComponent({
    name: 'Avatar',
    props: avatarProps,
    setup(props) {
        const { mergedClsPrefixRef } = _mixins_1.useConfig(props);
        let memoedTextHtml = null;
        const textRef = vue_1.ref(null);
        const selfRef = vue_1.ref(null);
        const adjustText = () => {
            const { value: textEl } = textRef;
            if (textEl) {
                if (memoedTextHtml === null || memoedTextHtml !== textEl.innerHTML) {
                    memoedTextHtml = textEl.innerHTML;
                    const { value: selfEl } = selfRef;
                    if (selfEl) {
                        const { offsetWidth: elWidth, offsetHeight: elHeight } = selfEl;
                        const { offsetWidth: textWidth, offsetHeight: textHeight } = textEl;
                        const radix = 0.9;
                        const ratio = Math.min((elWidth / textWidth) * radix, (elHeight / textHeight) * radix, 1);
                        textEl.style.transform = `translateX(-50%) translateY(-50%) scale(${ratio})`;
                    }
                }
            }
        };
        // Not Good Impl
        vue_1.onMounted(() => adjustText());
        vue_1.onUpdated(() => {
            adjustText();
        });
        const themeRef = _mixins_1.useTheme('Avatar', 'Avatar', index_cssr_1.default, styles_1.avatarLight, props, mergedClsPrefixRef);
        return {
            textRef,
            selfRef,
            mergedClsPrefix: mergedClsPrefixRef,
            cssVars: vue_1.computed(() => {
                const { size, round, circle } = props;
                const { self: { borderRadius, fontSize, color }, common: { cubicBezierEaseInOut } } = themeRef.value;
                let height;
                if (typeof size === 'number') {
                    height = `${size}px`;
                }
                else {
                    height = themeRef.value.self[_utils_1.createKey('height', size)];
                }
                return {
                    '--font-size': fontSize,
                    '--border-radius': round || circle ? '50%' : borderRadius,
                    '--color': color,
                    '--bezier': cubicBezierEaseInOut,
                    '--size': height
                };
            })
        };
    },
    render() {
        const { $slots, src, mergedClsPrefix } = this;
        return (vue_1.h("span", { ref: "selfRef", class: `${mergedClsPrefix}-avatar`, style: this.cssVars }, !$slots.default && src ? (vue_1.h("img", { src: src })) : (vue_1.h("span", { ref: "textRef", class: `${mergedClsPrefix}-avatar__text`, style: { background: this.color } }, $slots))));
    }
});
