"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPathLabel = exports.createSelectOptions = exports.traverseWithCallback = void 0;
function traverseWithCallback(options, beforeCallback, afterCallback) {
    if (Array.isArray(options)) {
        for (const option of options) {
            if (beforeCallback)
                beforeCallback(option);
            if (option.children) {
                traverseWithCallback(option.children, beforeCallback, afterCallback);
            }
            if (afterCallback)
                afterCallback(option);
        }
    }
}
exports.traverseWithCallback = traverseWithCallback;
function createSelectOptions(tmNodes, leafOnly) {
    const selectOptions = [];
    const path = [];
    traverseWithCallback(tmNodes, (tmNode) => {
        if (tmNode.isLeaf || !leafOnly) {
            if (tmNode.disabled)
                return;
            const { rawNode } = tmNode;
            path.push(rawNode);
            selectOptions.push({
                label: path.map((rawNodeInPath) => rawNodeInPath.label).join('/'),
                value: rawNode.value,
                path: Array.from(path)
            });
        }
    }, () => {
        path.pop();
    });
    return selectOptions;
}
exports.createSelectOptions = createSelectOptions;
function getPathLabel(node, separator) {
    const path = [];
    while (node) {
        path.push(node.rawNode.label);
        node = node.parent;
    }
    return path.reverse().join(separator);
}
exports.getPathLabel = getPathLabel;
