"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const seemly_1 = require("seemly");
const vue_1 = require("vue");
const input_1 = require("../../input");
const ColorInputUnit_1 = require("./ColorInputUnit");
exports.default = vue_1.defineComponent({
    name: 'ColorInput',
    props: {
        clsPrefix: {
            type: String,
            required: true
        },
        mode: {
            type: String,
            required: true
        },
        showAlpha: {
            type: Boolean,
            required: true
        },
        value: {
            // for hex to get percise value
            type: String,
            default: null
        },
        valueArr: {
            type: Array,
            default: null
        },
        onUpdateValue: {
            type: Function,
            required: true
        },
        onUpdateMode: {
            type: Function,
            required: true
        }
    },
    setup(props) {
        return {
            handleUnitUpdateValue(index, value) {
                const { showAlpha } = props;
                if (props.mode === 'hex') {
                    props.onUpdateValue((showAlpha ? seemly_1.toHexaString : seemly_1.toHexString)(value));
                    return;
                }
                let nextValueArr;
                if (props.valueArr === null) {
                    nextValueArr = [0, 0, 0, 0];
                }
                else {
                    nextValueArr = Array.from(props.valueArr);
                }
                switch (props.mode) {
                    case 'hsv':
                        nextValueArr[index] = value;
                        props.onUpdateValue((showAlpha ? seemly_1.toHsvaString : seemly_1.toHsvString)(nextValueArr));
                        break;
                    case 'rgb':
                        nextValueArr[index] = value;
                        props.onUpdateValue((showAlpha ? seemly_1.toRgbaString : seemly_1.toRgbString)(nextValueArr));
                        break;
                    case 'hsl':
                        nextValueArr[index] = value;
                        props.onUpdateValue((showAlpha ? seemly_1.toHslaString : seemly_1.toHslString)(nextValueArr));
                        break;
                }
            }
        };
    },
    render() {
        const { clsPrefix } = this;
        return (vue_1.h("div", { class: `${clsPrefix}-color-picker-input` },
            vue_1.h("div", { class: `${clsPrefix}-color-picker-input__mode`, onClick: this.onUpdateMode }, this.mode.toUpperCase() + (this.showAlpha ? 'A' : '')),
            vue_1.h(input_1.NInputGroup, null, {
                default: () => {
                    const { mode, valueArr, value, showAlpha } = this;
                    if (mode === 'hex') {
                        let hexValue = null;
                        try {
                            hexValue =
                                value === null
                                    ? null
                                    : (showAlpha ? seemly_1.toHexaString : seemly_1.toHexString)(value);
                        }
                        catch (_a) { }
                        return (vue_1.h(ColorInputUnit_1.default, { label: 'HEX', showAlpha: showAlpha, value: hexValue, onUpdateValue: (unitValue) => {
                                this.handleUnitUpdateValue(0, unitValue);
                            } }));
                    }
                    return (mode + (showAlpha ? 'a' : '')).split('').map((v, i) => (vue_1.h(ColorInputUnit_1.default, { label: v.toUpperCase(), value: valueArr === null ? null : valueArr[i], onUpdateValue: (unitValue) => {
                            this.handleUnitUpdateValue(i, unitValue);
                        } })));
                }
            })));
    }
});
