"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.menuItemProps = void 0;
const vue_1 = require("vue");
const vooks_1 = require("vooks");
const tooltip_1 = require("../../tooltip");
const MenuOptionContent_1 = require("./MenuOptionContent");
const use_menu_child_1 = require("./use-menu-child");
const _utils_1 = require("../../_utils");
exports.menuItemProps = Object.assign(Object.assign({}, use_menu_child_1.useMenuChildProps), { tmNode: {
        type: Object,
        required: true
    }, disabled: {
        type: Boolean,
        default: false
    }, icon: Function, onClick: Function });
exports.default = vue_1.defineComponent({
    name: 'MenuOption',
    props: exports.menuItemProps,
    setup(props) {
        const MenuChild = use_menu_child_1.useMenuChild(props);
        const { NSubmenu, NMenu } = MenuChild;
        const { props: menuProps, mergedClsPrefixRef, mergedCollapsedRef } = NMenu;
        const submenuDisabledRef = NSubmenu
            ? NSubmenu.mergedDisabledRef
            : { value: false };
        const mergedDisabledRef = vue_1.computed(() => {
            return submenuDisabledRef.value || props.disabled;
        });
        function doClick(e) {
            const { onClick } = props;
            if (onClick)
                onClick(e);
        }
        function handleClick(e) {
            if (!mergedDisabledRef.value) {
                NMenu.doSelect(props.internalKey, props.tmNode.rawNode);
                doClick(e);
            }
        }
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            dropdownPlacement: MenuChild.dropdownPlacement,
            paddingLeft: MenuChild.paddingLeft,
            iconMarginRight: MenuChild.iconMarginRight,
            maxIconSize: MenuChild.maxIconSize,
            activeIconSize: MenuChild.activeIconSize,
            mergedTheme: NMenu.mergedThemeRef,
            dropdownEnabled: vooks_1.useMemo(() => {
                return (props.root &&
                    mergedCollapsedRef.value &&
                    menuProps.mode !== 'horizontal' &&
                    !mergedDisabledRef.value);
            }),
            // Vue has bug when using vooks.useMemo
            // menu item state won't be updated...
            // a minimal reproduction is needed
            selected: vue_1.computed(() => {
                if (NMenu.mergedValueRef.value === props.internalKey)
                    return true;
                return false;
            }),
            mergedDisabled: mergedDisabledRef,
            handleClick
        };
    },
    render() {
        const { mergedClsPrefix } = this;
        return (vue_1.h("div", { role: "menuitem", class: [
                `${mergedClsPrefix}-menu-item`,
                {
                    [`${mergedClsPrefix}-menu-item--selected`]: this.selected,
                    [`${mergedClsPrefix}-menu-item--disabled`]: this.mergedDisabled
                }
            ] },
            vue_1.h(tooltip_1.NTooltip, { theme: this.mergedTheme.peers.Tooltip, themeOverrides: this.mergedTheme.peerOverrides.Tooltip, trigger: "hover", placement: this.dropdownPlacement, disabled: !this.dropdownEnabled || this.title === undefined }, {
                default: () => vue_1.h(_utils_1.render, { render: this.title }),
                trigger: () => (vue_1.h(MenuOptionContent_1.default, { clsPrefix: mergedClsPrefix, paddingLeft: this.paddingLeft, iconMarginRight: this.iconMarginRight, maxIconSize: this.maxIconSize, activeIconSize: this.activeIconSize, title: this.title, extra: this.extra, disabled: this.mergedDisabled, icon: this.icon, onClick: this.handleClick }))
            })));
    }
});
