"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const vooks_1 = require("vooks");
const checkbox_1 = require("../../checkbox");
const interface_1 = require("./interface");
exports.default = vue_1.defineComponent({
    name: 'NTransferListItem',
    props: {
        source: {
            type: Boolean,
            default: false
        },
        label: {
            type: String,
            required: true
        },
        value: {
            type: [String, Number],
            required: true
        },
        disabled: {
            type: Boolean,
            default: false
        }
    },
    setup(props) {
        const { source } = props;
        const { mergedClsPrefixRef, mergedThemeRef, srcCheckedValuesRef, tgtCheckedValuesRef, handleSrcCheckboxClick, handleTgtCheckboxClick
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
         } = vue_1.inject(interface_1.transferInjectionKey);
        const checkedRef = source
            ? vooks_1.useMemo(() => srcCheckedValuesRef.value.includes(props.value))
            : vooks_1.useMemo(() => tgtCheckedValuesRef.value.includes(props.value));
        const handleClick = source
            ? () => {
                if (!props.disabled) {
                    handleSrcCheckboxClick(!checkedRef.value, props.value);
                }
            }
            : () => {
                if (!props.disabled) {
                    handleTgtCheckboxClick(!checkedRef.value, props.value);
                }
            };
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            mergedTheme: mergedThemeRef,
            checked: checkedRef,
            handleClick
        };
    },
    render() {
        const { disabled, mergedTheme, mergedClsPrefix, label, checked, source } = this;
        return (vue_1.h("div", { class: [
                `${mergedClsPrefix}-transfer-list-item`,
                disabled && `${mergedClsPrefix}-transfer-list-item--disabled`,
                source
                    ? `${mergedClsPrefix}-transfer-list-item--source`
                    : `${mergedClsPrefix}-transfer-list-item--target`
            ], onClick: this.handleClick },
            vue_1.h("div", { class: `${mergedClsPrefix}-transfer-list-item__checkbox` },
                vue_1.h(checkbox_1.NCheckbox, { theme: mergedTheme.peers.Checkbox, themeOverrides: mergedTheme.peerOverrides.Checkbox, disabled: disabled, checked: checked })),
            vue_1.h("div", { class: `${mergedClsPrefix}-transfer-list-item__label` }, label)));
    }
});
