"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const _mixins_1 = require("../../_mixins");
const _utils_1 = require("../../_utils");
const styles_1 = require("../styles");
const header_cssr_1 = require("./styles/header.cssr");
const headerProps = Object.assign(Object.assign({}, _mixins_1.useTheme.props), { type: {
        type: String,
        default: 'default'
    }, prefix: String, alignText: {
        type: Boolean,
        default: false
    } });
// eslint-disable-next-line @typescript-eslint/explicit-function-return-type
exports.default = (level) => vue_1.defineComponent({
    name: `H${level}`,
    props: headerProps,
    setup(props) {
        const { mergedClsPrefixRef } = _mixins_1.useConfig(props);
        const themeRef = _mixins_1.useTheme('Typography', 'H', header_cssr_1.default, styles_1.typographyLight, props, mergedClsPrefixRef);
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            cssVars: vue_1.computed(() => {
                const { type } = props;
                const { common: { cubicBezierEaseInOut }, self: { headerFontWeight, headerTextColor, [_utils_1.createKey('headerPrefixWidth', level)]: prefixWidth, [_utils_1.createKey('headerFontSize', level)]: fontSize, [_utils_1.createKey('headerMargin', level)]: margin, [_utils_1.createKey('headerBarWidth', level)]: barWidth, [_utils_1.createKey('headerBarColor', type)]: barColor } } = themeRef.value;
                return {
                    '--bezier': cubicBezierEaseInOut,
                    '--font-size': fontSize,
                    '--margin': margin,
                    '--bar-color': barColor,
                    '--bar-width': barWidth,
                    '--font-weight': headerFontWeight,
                    '--text-color': headerTextColor,
                    '--prefix-width': prefixWidth
                };
            })
        };
    },
    render() {
        const { prefix, alignText, mergedClsPrefix, cssVars, $slots } = this;
        return vue_1.h(`h${level}`, {
            class: [
                `${mergedClsPrefix}-h`,
                `${mergedClsPrefix}-h${level}`,
                {
                    [`${mergedClsPrefix}-h--prefix-bar`]: prefix,
                    [`${mergedClsPrefix}-h--align-text`]: alignText
                }
            ],
            style: cssVars
        }, $slots);
    }
});
